package org.apache.bcel.generic;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.generic.BranchInstruction;
import org.apache.bcel.generic.ClassGenException;
import org.apache.bcel.generic.InstructionHandle;
import org.apache.bcel.generic.StackConsumer;
import org.apache.bcel.generic.StackProducer;
import org.apache.bcel.generic.VariableLengthInstruction;
import org.apache.bcel.util.ByteSequence;

public abstract class Select extends BranchInstruction implements VariableLengthInstruction, StackConsumer, StackProducer {
  @Deprecated
  protected int[] match;
  
  @Deprecated
  protected int[] indices;
  
  @Deprecated
  protected InstructionHandle[] targets;
  
  @Deprecated
  protected int fixed_length;
  
  @Deprecated
  protected int match_length;
  
  @Deprecated
  protected int padding;
  
  Select() {}
  
  Select(short opcode, int[] match, InstructionHandle[] targets, InstructionHandle defaultTarget) {
    super(opcode, (InstructionHandle)null);
    this.match = match;
    this.targets = targets;
    setTarget(defaultTarget);
    for (InstructionHandle target2 : targets)
      notifyTarget((InstructionHandle)null, target2, this); 
    if ((this.match_length = match.length) != targets.length)
      throw new ClassGenException("Match and target array have not the same length: Match length: " + match.length + " Target length: " + targets.length); 
    this.indices = new int[this.match_length];
  }
  
  protected Object clone() throws CloneNotSupportedException {
    org.apache.bcel.generic.Select copy = (org.apache.bcel.generic.Select)super.clone();
    copy.match = (int[])this.match.clone();
    copy.indices = (int[])this.indices.clone();
    copy.targets = (InstructionHandle[])this.targets.clone();
    return copy;
  }
  
  public boolean containsTarget(InstructionHandle ih) {
    if (getTarget() == ih)
      return true; 
    for (InstructionHandle target2 : this.targets) {
      if (target2 == ih)
        return true; 
    } 
    return false;
  }
  
  void dispose() {
    super.dispose();
    for (InstructionHandle target2 : this.targets)
      target2.removeTargeter(this); 
  }
  
  public void dump(DataOutputStream out) throws IOException {
    out.writeByte(getOpcode());
    for (int i = 0; i < this.padding; i++)
      out.writeByte(0); 
    setIndex(getTargetOffset());
    out.writeInt(getIndex());
  }
  
  final int getFixedLength() {
    return this.fixed_length;
  }
  
  public int[] getIndices() {
    return this.indices;
  }
  
  final int getIndices(int index) {
    return this.indices[index];
  }
  
  final int getMatch(int index) {
    return this.match[index];
  }
  
  final int getMatchLength() {
    return this.match_length;
  }
  
  public int[] getMatchs() {
    return this.match;
  }
  
  final int getPadding() {
    return this.padding;
  }
  
  final InstructionHandle getTarget(int index) {
    return this.targets[index];
  }
  
  public InstructionHandle[] getTargets() {
    return this.targets;
  }
  
  protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
    this.padding = (4 - bytes.getIndex() % 4) % 4;
    for (int i = 0; i < this.padding; i++)
      bytes.readByte(); 
    setIndex(bytes.readInt());
  }
  
  final void setFixedLength(int fixedLength) {
    this.fixed_length = fixedLength;
  }
  
  final int setIndices(int i, int value) {
    this.indices[i] = value;
    return value;
  }
  
  final void setIndices(int[] array) {
    this.indices = array;
  }
  
  final void setMatch(int index, int value) {
    this.match[index] = value;
  }
  
  final int setMatchLength(int matchLength) {
    this.match_length = matchLength;
    return matchLength;
  }
  
  final void setMatches(int[] array) {
    this.match = array;
  }
  
  public void setTarget(int i, InstructionHandle target) {
    notifyTarget(this.targets[i], target, this);
    this.targets[i] = target;
  }
  
  final void setTargets(InstructionHandle[] array) {
    this.targets = array;
  }
  
  public String toString(boolean verbose) {
    StringBuilder buf = new StringBuilder(super.toString(verbose));
    if (verbose) {
      for (int i = 0; i < this.match_length; i++) {
        String s = "null";
        if (this.targets[i] != null)
          s = this.targets[i].getInstruction().toString(); 
        buf.append("(").append(this.match[i]).append(", ").append(s).append(" = {").append(this.indices[i]).append("})");
      } 
    } else {
      buf.append(" ...");
    } 
    return buf.toString();
  }
  
  protected int updatePosition(int offset, int maxOffset) {
    setPosition(getPosition() + offset);
    short oldLength = (short)getLength();
    this.padding = (4 - (getPosition() + 1) % 4) % 4;
    setLength((short)(this.fixed_length + this.padding));
    return getLength() - oldLength;
  }
  
  public void updateTarget(InstructionHandle oldIh, InstructionHandle newIh) {
    boolean targeted = false;
    if (getTarget() == oldIh) {
      targeted = true;
      setTarget(newIh);
    } 
    for (int i = 0; i < this.targets.length; i++) {
      if (this.targets[i] == oldIh) {
        targeted = true;
        setTarget(i, newIh);
      } 
    } 
    if (!targeted)
      throw new ClassGenException("Not targeting " + oldIh); 
  }
}
